@@ -17,6 +17,8 @@ mod disk;
 
 use crate::Child;
 use canonical::{Canon, CanonError, Id};
+use canonical_derive::Canon;
+
 use lazy_static::lazy_static;
 use parking_lot::{RwLock, RwLockWriteGuard};
 
@@ -103,19 +105,20 @@ impl<B> BackendCtor<B> {
 }
 
 /// Id of a persisted GenericTree
+#[derive(Canon, Clone, Copy, Debug)]
 pub struct PersistedId(Id);
 
 impl PersistedId {
-    /// Restore a GenericTree from a persistance backend.
+    /// Restore a GenericTree from a persistence backend.
     pub fn restore(&self) -> Result<GenericTree, PersistError> {
-        Persistance::get(&self.0)
+        Persistence::get(&self.0)
     }
 }
 
-/// The singleton interface to the persistance layer
-pub struct Persistance;
+/// The singleton interface to the persistence layer
+pub struct Persistence;
 
-impl Persistance {
+impl Persistence {
     /// Persist the given Compound to a backend
     pub fn persist<C, A, B>(
         ctor: &BackendCtor<B>,
